@@ -315,7 +315,8 @@ def lazy_string_cast(model_parameters={}, provide_defaults=True):
         return value
 
     def cast_list(inner_cast_func, key, value):
-        value = shlex.split(value)
+        value = shlex.split(value.replace("\\", "_windowsCompat_"))
+        value = [a.replace("_windowsCompat_", "\\") for a in value]
         if inner_cast_func is not None:
             value = [inner_cast_func(a) for a in value]
         return value
@@ -623,7 +624,7 @@ class Config(MutableMapping):
         :param stream: the configuration to be loaded using ``yaml.load``.
         :type stream: stream object
         """
-        config = yaml.load(stream)
+        config = yaml.safe_load(stream)
         if not isinstance(config, dict):
             return
         for section, options in config.items():
